@@ -143,6 +143,6 @@ def activation_energy(path, ion):
             remaning_file, method = os.path.split(r)
             remaning_file, temperature = os.path.split(remaning_file)
             if str(ion) in list(map(lambda x: os.path.splitext(x)[0], f)):
-                gradient_and_ion[temperature] = full_path_data
+                gradient_and_ion[temperature] = full_path_data[0]
     return gradient_and_ion
 
